pub fn argument_from_sunk_cost() -> SchemeSpecExpand description
Argument from Sunk Cost (Walton 2008 p.340) — distinct from Waste: emphasises the prior commitment as a reason for continuation.
pub fn argument_from_sunk_cost() -> SchemeSpecArgument from Sunk Cost (Walton 2008 p.340) — distinct from Waste: emphasises the prior commitment as a reason for continuation.